"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Client = void 0;
const crypto_1 = require("crypto");
const axios_1 = __importDefault(require("axios"));
const form_data_1 = __importDefault(require("form-data"));
const nanoid_1 = require("nanoid");
class Client {
    constructor(params) {
        this.endpoint = `https://iot.${params.regionId}.aliyuncs.com`;
        this.method = 'POST';
        this.accessKeyId = params.accessKeyId;
        this.accessKeySecret = params.accessKeySecret;
        this.regionId = params.regionId;
        this.format = 'JSON';
        this.signatureVersion = '1.0';
        this.signatureMethod = 'HMAC-SHA1';
        if (params.version)
            this.version = params.version;
        else
            this.version = '2018-01-20';
    }
    request(params) {
        const requestParams = this.__sign__(this.__mergeRequestParameters__(params), this.accessKeySecret);
        const form = new form_data_1.default();
        Object.entries(requestParams).forEach(([k, v]) => form.append(k, v));
        return axios_1.default.post(this.endpoint, form, { headers: form.getHeaders() });
    }
    /**
     * 将调用 API 的请求参数与公共参数合并
     * @param requestParameters API 请求参数
     */
    __mergeRequestParameters__(requestParameters) {
        return Object.assign({
            Format: this.format,
            Version: this.version,
            AccessKeyId: this.accessKeyId,
            SignatureMethod: this.signatureMethod,
            Timestamp: new Date().toISOString(),
            SignatureVersion: this.signatureVersion,
            SignatureNonce: nanoid_1.nanoid(),
            RegionId: this.regionId
        }, requestParameters);
    }
    __sign__(params, accessKeySecret) {
        const queryString = Object.entries(params)
            .sort()
            .map(([k, v]) => [encodeURIComponent(k), encodeURIComponent(v)].join('='))
            .join('&');
        const stringToSign = `${this.method}&${encodeURIComponent('/')}&${encodeURIComponent(queryString)}`;
        // https://help.aliyun.com/document_detail/30563.html#h2-url-1
        // ❗❗❗ 计算签名时，使用的 Key 就是你的 AccessKeySecret 并加上一个与号 & 字符（ASCII:38）
        // 使用的哈希算法是 SHA1
        const signature = crypto_1.createHmac('sha1', `${accessKeySecret}&`)
            .update(stringToSign)
            .digest('base64');
        // 使用 POST 请求时，签名不要进行 URL 编码
        params.Signature = signature;
        return params;
    }
}
exports.Client = Client;
